# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.4

([Full Changelog](https://github.com/jupyter/notebook_shim/compare/v0.2.3...eb748573d2af505c6846fbf2597ec56447c0d6e8))

### Maintenance and upkeep improvements

- Fix extension discovery warning [#31](https://github.com/jupyter/notebook_shim/pull/31) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter/notebook_shim/graphs/contributors?from=2023-04-24&to=2024-02-14&type=c))

[@Zsailer](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3AZsailer+updated%3A2023-04-24..2024-02-14&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.3

([Full Changelog](https://github.com/jupyter/notebook_shim/compare/v0.2.2...bb84e6475a757b6299cb07ec3ce027a8c57d052e))

### Maintenance and upkeep improvements

- Add show_banner to ignored_traits [#29](https://github.com/jupyter/notebook_shim/pull/29) ([@echarles](https://github.com/echarles))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter/notebook_shim/graphs/contributors?from=2022-11-03&to=2023-04-24&type=c))

[@echarles](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3Aecharles+updated%3A2022-11-03..2023-04-24&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3AZsailer+updated%3A2022-11-03..2023-04-24&type=Issues)

## 0.2.2

([Full Changelog](https://github.com/jupyter/notebook_shim/compare/v0.2.0...e1f1219888d9bfa69fc0e1f130f6f1bcf3825fcb))

### Bugs fixed

- Fixes #7 [#24](https://github.com/jupyter/notebook_shim/pull/24) ([@dleen](https://github.com/dleen))
- Add config file [#23](https://github.com/jupyter/notebook_shim/pull/23) ([@dleen](https://github.com/dleen))

### Maintenance and upkeep improvements

- add releaser v2 workflows [#25](https://github.com/jupyter/notebook_shim/pull/25) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter/notebook_shim/graphs/contributors?from=2022-10-17&to=2022-11-03&type=c))

[@dleen](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3Adleen+updated%3A2022-10-17..2022-11-03&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3AZsailer+updated%3A2022-10-17..2022-11-03&type=Issues)

## 0.2.1

([Full Changelog](https://github.com/jupyter/notebook_shim/compare/v0.2.0...b72af7411fa41115c3025a95f261e10bf0221fb0))

### Bugs fixed

- Add config file [#23](https://github.com/jupyter/notebook_shim/pull/23) ([@dleen](https://github.com/dleen))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter/notebook_shim/graphs/contributors?from=2022-10-17&to=2022-11-02&type=c))

[@dleen](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3Adleen+updated%3A2022-10-17..2022-11-02&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/jupyter/notebook_shim/compare/v0.1.0...4e4228d7bb2d2e04cc204db3de7f2f567d65c38a))

### Enhancements made

- raise ceiling on jupyter_server dependency to < 3 [#12](https://github.com/jupyter/notebook_shim/pull/12) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- remove dev version [#15](https://github.com/jupyter/notebook_shim/pull/15) ([@Zsailer](https://github.com/Zsailer))
- switch to hatch build backend [#14](https://github.com/jupyter/notebook_shim/pull/14) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter/notebook_shim/graphs/contributors?from=2022-02-10&to=2022-10-17&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3Ablink1073+updated%3A2022-02-10..2022-10-17&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3Ajtpio+updated%3A2022-02-10..2022-10-17&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter%2Fnotebook_shim+involves%3AZsailer+updated%3A2022-02-10..2022-10-17&type=Issues)

## 0.1.0

([Full Changelog](https://github.com/jupyterlab/notebook_shim/compare/first-commit...5b433fa298f741c7d71c9a3e7e85f17b2207300f))

### Enhancements made

- [WIP] Move over initial shim logic [#1](https://github.com/jupyterlab/notebook_shim/pull/1) ([@Zsailer](https://github.com/Zsailer))

### Bugs fixed

- Port missing logic and get unit tests working [#5](https://github.com/jupyterlab/notebook_shim/pull/5) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- Add a test workflow on CI [#4](https://github.com/jupyterlab/notebook_shim/pull/4) ([@jtpio](https://github.com/jtpio))
- Add `check-release` workflow on CI [#3](https://github.com/jupyterlab/notebook_shim/pull/3) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/notebook_shim/graphs/contributors?from=2022-01-19&to=2022-02-10&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fnotebook_shim+involves%3Ajtpio+updated%3A2022-01-19..2022-02-10&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fnotebook_shim+involves%3Awelcome+updated%3A2022-01-19..2022-02-10&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyterlab%2Fnotebook_shim+involves%3AZsailer+updated%3A2022-01-19..2022-02-10&type=Issues)
